@@ -2,6 +2,7 @@ from flask import g
 import enum
 from hiddifypanel.models import User,Domain,BoolConfig,StrConfig,DomainType,ConfigEnum,get_hconfigs,get_hdomains,hconfig,Proxy
 import yaml
+import json
 from hiddifypanel.panel import hiddify
 def all_proxies():
     all_proxies=hiddify.get_available_proxies()
@@ -99,22 +100,15 @@ def make_proxy(proxy,domain_db):
         base['mode']='Fake'
     elif l3=="http" and not hconfig(ConfigEnum.http_proxy_enable,child_id):
         return None    
+    path={
+        'vless':f'{hconfigs[ConfigEnum.path_vless]}',
+        'trojan': f'{hconfigs[ConfigEnum.path_trojan]}',
+        'vmess':f'{hconfigs[ConfigEnum.path_vmess]}',
+        'ss':f'{hconfigs[ConfigEnum.path_ss]}',
+        'v2ray':f'{hconfigs[ConfigEnum.path_ss]}'
+    }
 
-    ws_path={'vless':f'/{hconfigs[ConfigEnum.proxy_path]}/vlessws',
-            'trojan': f'/{hconfigs[ConfigEnum.proxy_path]}/trojanws',
-            'vmess':f'/{hconfigs[ConfigEnum.proxy_path]}/vmessws',
-            'v2ray':f'/{hconfigs[ConfigEnum.proxy_path]}/v2ray/'
-    }
-    tcp_path={'vless':f'/{hconfigs[ConfigEnum.proxy_path]}/vltc',
-            'trojan': f'/{hconfigs[ConfigEnum.proxy_path]}/trtc',
-            'vmess':f'/{hconfigs[ConfigEnum.proxy_path]}/vmtc'
-    }
     
-    grpc_service_name={
-        'vless':f'{hconfigs[ConfigEnum.proxy_path]}-vlgrpc',
-        'vmess':f'{hconfigs[ConfigEnum.proxy_path]}-vmgrpc',
-        'trojan': f'{hconfigs[ConfigEnum.proxy_path]}-trgrpc'
-    }    
 
     if base["proto"] in ['v2ray','ss','ssr']:
         base['chipher']='chacha20-ietf-poly1305'
@@ -142,18 +136,19 @@ def make_proxy(proxy,domain_db):
         return {**base, 'transport': 'tcp', 'l3': 'xtls', 'alpn':'h2'}
     if "tcp" in name:
         base['transport']='tcp'
-        base['path']=tcp_path[base["proto"]]
+        base['path']=f'/{path[base["proto"]]}{hconfigs[ConfigEnum.path_tcp]}'
         return base   
     if proxy.transport in ["ws","WS"]:
         base['transport']='ws'
-        base['path']=ws_path[base["proto"]]
+        base['path']=f'/{path[base["proto"]]}{hconfigs[ConfigEnum.path_ws]}'
         base["host"]=domain
         return base
     
     if proxy.transport == "grpc":
         base['transport']='grpc'
         base['grpc_mode']="multi"
-        base['grpc_service_name']=grpc_service_name[base["proto"]]
+        base['grpc_service_name']=f'{path[base["proto"]]}{hconfigs[ConfigEnum.path_grpc]}'
+        base['path']=base['grpc_service_name']
         return base
     
     if "h1" in name:
@@ -168,8 +163,27 @@ def to_link(proxy):
 
     name_link=proxy["name"]+"_"+proxy['extra_info']
     if proxy['proto']=='vmess':
+        print(proxy)
         vmess_type= 'http' if proxy["transport"]=='tcp' else 'none'
-        return pbase64(f'vmess://{{"v":"2", "ps":"{name_link}", "add":"{proxy["server"]}", "port":"{proxy["port"]}", "id":"{proxy["uuid"]}", "aid":"0", "scy":"auto", "net":"{proxy["transport"]}", "type":"none", "host":"{proxy.get("host","")}", "path":"{proxy["path"] if "path" in proxy else ""}", "tls":"{proxy["l3"]}", "sni":"{proxy["sni"]}","fp":"{proxy["fingerprint"]}"}}')
+        vmess_data={"v":"2",
+                     "ps":name_link, 
+                     "add":proxy['server'],
+                      "port":proxy['port'],
+                      "id":proxy["uuid"], 
+                      "aid":"0", 
+                      "scy":"auto", 
+                      "net":proxy["transport"], 
+                      "type":proxy['grpc_mode'] if 'grpc_mode' in proxy else "none", 
+                      "host":proxy.get("host",""), 
+                      "path":proxy["path"] if "path" in proxy else "",
+                      "tls":proxy["l3"], 
+                      "sni":proxy["sni"],
+                      "fp":proxy["fingerprint"]
+                      }
+
+
+
+        return pbase64(f'vmess://{json.dumps(vmess_data)}')
     if proxy['proto']=="ssr":
         baseurl=f'ssr://proxy["encryption"]:{proxy["uuid"]}@{proxy["server"]}:{proxy["port"]}'
         return None
