@@ -163,7 +163,7 @@ def get_common_data(user_uuid,mode,no_domain=False,filter_domain=None):
         'user':user,
         'domain':domain,       
         'mode':mode,
-        'fake_ip_for_sub_link':datetime.date.today().strftime("20.%y.%m.%d:%H"),
+        'fake_ip_for_sub_link':datetime.datetime.now().strftime(f"20.%y.%m.%d:{max(1,datetime.datetime.now().hour)}"),
         'usage_limit_b':int(user.usage_limit_GB*1024*1024*1024),
         'usage_current_b':int(user.current_usage_GB*1024*1024*1024),
         'expire_s':expire_s,
